@@ -1,4 +1,4 @@
-/* xml++.cc
+/* domparser.cc
  * libxml++ and this file are copyright (C) 2000 by Ari Johnson, and
  * are covered by the GNU Lesser General Public License, which should be
  * included with libxml++ as the file COPYING.
@@ -49,7 +49,11 @@ void DomParser::parse_file(const Glib::ustring& filename)
 
   if(!context_)
   {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   if(context_->directory == 0)
@@ -72,7 +76,11 @@ void DomParser::parse_memory_raw(const unsigned char* contents, size_type bytes_
 
   if(!context_)
   {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   parse_context();
@@ -91,6 +99,15 @@ void DomParser::parse_context()
   //and the implementation of xmlParseMemory(), in xmlSaxParseMemoryWithData().
   initialize_context();
 
+  if(!context_)
+  {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
+    throw internal_error("Context not initialized");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
+  }
+
   xmlParseDocument(context_);
 
   check_for_exception();
@@ -98,21 +115,32 @@ void DomParser::parse_context()
   if(!context_->wellFormed)
   {
     release_underlying(); //Free doc_;
+
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error("Document not well-formed.");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   if(context_->errNo != 0)
   {
-    release_underlying();
     std::ostringstream o;
     o << "libxml error " << context_->errNo;
+
+    release_underlying();
+
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error(o.str());
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   doc_ = new Document(context_->myDoc);
   // This is to indicate to release_underlying that we took the
   // ownership on the doc.
-  context_->myDoc = NULL;
+  context_->myDoc = 0;
 
   //Free the parse context, but keep the document alive so people can navigate the DOM tree:
   //TODO: Why not keep the context alive too?
@@ -137,7 +165,11 @@ void DomParser::parse_stream(std::istream& in)
 
   if(!context_)
   {
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw internal_error("Couldn't create parsing context");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   initialize_context();
@@ -160,21 +192,32 @@ void DomParser::parse_stream(std::istream& in)
   if(!context_->wellFormed)
   {
     release_underlying(); //Free doc_;
+
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error("Document not well-formed.");
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   if(context_->errNo != 0)
   {
     std::ostringstream o;
     o << "libxml error " << context_->errNo;
+
     release_underlying();
+
+    #ifdef LIBXMLCPP_EXCEPTIONS_ENABLED
     throw parse_error(o.str());
+    #else
+    return;
+    #endif //LIBXMLCPP_EXCEPTIONS_ENABLED
   }
 
   doc_ = new Document(context_->myDoc);
   // This is to indicate to release_underlying that we took the
   // ownership on the doc.
-  context_->myDoc = NULL;
+  context_->myDoc = 0;
 
 
   //Free the parse context, but keep the document alive so people can navigate the DOM tree:
